
Sphinx documentation generator for django apps
==============================================

This django app provides a management command to generate sphinx documentation for django apps.

Installing
----------

